@@ -199,7 +199,7 @@ struct ao2_container *ast_channel_cache_all(void);
 /*!
  * \since 12
  * \brief A topic which publishes the events for all channels.
- * \retval Topic for all channel events.
+ * \return Topic for all channel events.
  */
 struct stasis_topic *ast_channel_topic_all(void);
 
@@ -207,7 +207,7 @@ struct stasis_topic *ast_channel_topic_all(void);
  * \since 12
  * \brief Secondary channel cache, indexed by name.
  *
- * \retval Cache of \ref ast_channel_snapshot.
+ * \return Cache of \ref ast_channel_snapshot.
  */
 struct ao2_container *ast_channel_cache_by_name(void);
 
@@ -215,7 +215,7 @@ struct ao2_container *ast_channel_cache_by_name(void);
  * \since 12
  * \brief Message type for \ref ast_channel_snapshot_update.
  *
- * \retval Message type for \ref ast_channel_snapshot_update.
+ * \return Message type for \ref ast_channel_snapshot_update.
  */
 struct stasis_message_type *ast_channel_snapshot_type(void);
 
@@ -228,7 +228,7 @@ struct stasis_message_type *ast_channel_snapshot_type(void);
  *
  * \param chan The channel from which to generate a snapshot
  *
- * \retval pointer on success (must be unreffed)
+ * \return pointer on success (must be unreffed)
  * \retval NULL on error
  */
 struct ast_channel_snapshot *ast_channel_snapshot_create(
@@ -239,9 +239,9 @@ struct ast_channel_snapshot *ast_channel_snapshot_create(
  * \brief Obtain the latest \ref ast_channel_snapshot from the \ref stasis cache. This is
  * an ao2 object, so use \ref ao2_cleanup() to deallocate.
  *
- * \param unique_id The channel's unique ID
+ * \param uniqueid The channel's unique ID
  *
- * \retval A \ref ast_channel_snapshot on success
+ * \return A \ref ast_channel_snapshot on success
  * \retval NULL on error
  */
 struct ast_channel_snapshot *ast_channel_snapshot_get_latest(const char *uniqueid);
@@ -253,7 +253,7 @@ struct ast_channel_snapshot *ast_channel_snapshot_get_latest(const char *uniquei
  *
  * \param name The channel's name
  *
- * \retval A \ref ast_channel_snapshot on success
+ * \return A \ref ast_channel_snapshot on success
  * \retval NULL on error
  */
 struct ast_channel_snapshot *ast_channel_snapshot_get_latest_by_name(const char *name);
@@ -285,7 +285,7 @@ void ast_channel_publish_final_snapshot(struct ast_channel *chan);
  *             \c NULL, ast_json_null() is put into the object.
  *
  * \return \ref ast_channel_blob message.
- * \return \c NULL on error
+ * \retval NULL on error
  */
 struct stasis_message *ast_channel_blob_create(struct ast_channel *chan,
 	struct stasis_message_type *type, struct ast_json *blob);
@@ -301,7 +301,7 @@ struct stasis_message *ast_channel_blob_create(struct ast_channel *chan,
  *             \c NULL, ast_json_null() is put into the object.
  *
  * \return \ref ast_channel_blob message.
- * \return \c NULL on error
+ * \retval NULL on error
  */
 struct stasis_message *ast_channel_blob_create_from_cache(
 	const char *uniqueid, struct stasis_message_type *type,
@@ -317,7 +317,7 @@ struct stasis_message *ast_channel_blob_create_from_cache(
  * \param blob The JSON blob that defines the data of this \ref ast_multi_channel_blob
  *
  * \return \ref ast_multi_channel_blob object
- * \return \c NULL on error
+ * \retval NULL on error
 */
 struct ast_multi_channel_blob *ast_multi_channel_blob_create(struct ast_json *blob);
 
@@ -334,7 +334,7 @@ struct ast_multi_channel_blob *ast_multi_channel_blob_create(struct ast_json *bl
  * to retrieve
  * \param role The role associated with the channel snapshot
  *
- * \retval \ref ast_channel_snapshot matching the role on success
+ * \return \ref ast_channel_snapshot matching the role on success
  * \retval NULL on error or not found for the role specified
  */
 struct ast_channel_snapshot *ast_multi_channel_blob_get_channel(
@@ -355,7 +355,7 @@ struct ast_channel_snapshot *ast_multi_channel_blob_get_channel(
  * retrieve
  * \param role The role associated with the channel snapshots
  *
- * \retval A container containing all \ref ast_channel_snapshot objects matching
+ * \return A container containing all \ref ast_channel_snapshot objects matching
  * the role on success.
  * \retval NULL on error or not found for the role specified
  */
@@ -369,7 +369,7 @@ struct ao2_container *ast_multi_channel_blob_get_channels(
  *
  * \param obj Channel blob object.
  * \return Type field value from the blob.
- * \return \c NULL on error.
+ * \retval NULL on error.
  */
 struct ast_json *ast_multi_channel_blob_get_json(struct ast_multi_channel_blob *obj);
 
@@ -399,8 +399,6 @@ void ast_multi_channel_blob_add_channel(struct ast_multi_channel_blob *obj,
  * \param blob The blob being published. (NULL if no blob)
  *
  * \note This will use the current snapshot on the channel and will not generate a new one.
- *
- * \return Nothing
  */
 void ast_channel_publish_blob(struct ast_channel *chan, struct stasis_message_type *type,
 	struct ast_json *blob);
@@ -416,8 +414,6 @@ void ast_channel_publish_blob(struct ast_channel *chan, struct stasis_message_ty
  * \note As this only accesses the uniqueid and topic of the channel - neither of
  * which should ever be changed on a channel anyhow - a channel does not have to
  * be locked when calling this function.
- *
- * \return Nothing
  */
 void ast_channel_publish_cached_blob(struct ast_channel *chan, struct stasis_message_type *type,
 	struct ast_json *blob);
@@ -466,7 +462,7 @@ void ast_channel_publish_snapshot(struct ast_channel *chan);
 
 /*!
  * \since 12
- * \brief Publish a \ref ast_channel_varset for a channel.
+ * \brief Publish a \ref ast_channel_publish_varset for a channel.
  *
  * \pre chan is locked
  *
@@ -481,7 +477,7 @@ void ast_channel_publish_varset(struct ast_channel *chan,
  * \since 12
  * \brief Message type for when a channel dials another channel
  *
- * \retval A stasis message type
+ * \return A stasis message type
  */
 struct stasis_message_type *ast_channel_dial_type(void);
 
@@ -489,7 +485,7 @@ struct stasis_message_type *ast_channel_dial_type(void);
  * \since 12
  * \brief Message type for when a variable is set on a channel.
  *
- * \retval A stasis message type
+ * \return A stasis message type
  */
 struct stasis_message_type *ast_channel_varset_type(void);
 
@@ -497,7 +493,7 @@ struct stasis_message_type *ast_channel_varset_type(void);
  * \since 12
  * \brief Message type for when a hangup is requested on a channel.
  *
- * \retval A stasis message type
+ * \return A stasis message type
  */
 struct stasis_message_type *ast_channel_hangup_request_type(void);
 
@@ -505,7 +501,7 @@ struct stasis_message_type *ast_channel_hangup_request_type(void);
  * \since 16
  * \brief Message type for when a channel is being masqueraded
  *
- * \retval A stasis message type
+ * \return A stasis message type
  */
 struct stasis_message_type *ast_channel_masquerade_type(void);
 
@@ -513,7 +509,7 @@ struct stasis_message_type *ast_channel_masquerade_type(void);
  * \since 12
  * \brief Message type for when DTMF begins on a channel.
  *
- * \retval A stasis message type
+ * \return A stasis message type
  */
 struct stasis_message_type *ast_channel_dtmf_begin_type(void);
 
@@ -521,22 +517,29 @@ struct stasis_message_type *ast_channel_dtmf_begin_type(void);
  * \since 12
  * \brief Message type for when DTMF ends on a channel.
  *
- * \retval A stasis message type
+ * \return A stasis message type
  */
 struct stasis_message_type *ast_channel_dtmf_end_type(void);
 
 /*!
  * \brief Message type for when a hook flash occurs on a channel.
  *
- * \retval A stasis message type
+ * \return A stasis message type
  */
 struct stasis_message_type *ast_channel_flash_type(void);
 
+/*!
+ * \brief Message type for when a wink occurs on a channel.
+ *
+ * \return A stasis message type
+ */
+struct stasis_message_type *ast_channel_wink_type(void);
+
 /*!
  * \since 12
  * \brief Message type for when a channel is placed on hold.
  *
- * \retval A stasis message type
+ * \return A stasis message type
  */
 struct stasis_message_type *ast_channel_hold_type(void);
 
@@ -544,7 +547,7 @@ struct stasis_message_type *ast_channel_hold_type(void);
  * \since 12
  * \brief Message type for when a channel is removed from hold.
  *
- * \retval A stasis message type
+ * \return A stasis message type
  */
 struct stasis_message_type *ast_channel_unhold_type(void);
 
@@ -552,7 +555,7 @@ struct stasis_message_type *ast_channel_unhold_type(void);
  * \since 12
  * \brief Message type for when a channel starts spying on another channel
  *
- * \retval A stasis message type
+ * \return A stasis message type
  */
 struct stasis_message_type *ast_channel_chanspy_start_type(void);
 
@@ -560,7 +563,7 @@ struct stasis_message_type *ast_channel_chanspy_start_type(void);
  * \since 12
  * \brief Message type for when a channel stops spying on another channel
  *
- * \retval A stasis message type
+ * \return A stasis message type
  */
 struct stasis_message_type *ast_channel_chanspy_stop_type(void);
 
@@ -568,7 +571,7 @@ struct stasis_message_type *ast_channel_chanspy_stop_type(void);
  * \since 12
  * \brief Message type for a fax operation
  *
- * \retval A stasis message type
+ * \return A stasis message type
  */
 struct stasis_message_type *ast_channel_fax_type(void);
 
@@ -576,7 +579,7 @@ struct stasis_message_type *ast_channel_fax_type(void);
  * \since 12
  * \brief Message type for hangup handler related actions
  *
- * \retval A stasis message type
+ * \return A stasis message type
  */
 struct stasis_message_type *ast_channel_hangup_handler_type(void);
 
@@ -584,7 +587,7 @@ struct stasis_message_type *ast_channel_hangup_handler_type(void);
  * \since 12
  * \brief Message type for starting monitor on a channel
  *
- * \retval A stasis message type
+ * \return A stasis message type
  */
 struct stasis_message_type *ast_channel_monitor_start_type(void);
 
@@ -592,7 +595,7 @@ struct stasis_message_type *ast_channel_monitor_start_type(void);
  * \since 12
  * \brief Message type for stopping monitor on a channel
  *
- * \retval A stasis message type
+ * \return A stasis message type
  */
 struct stasis_message_type *ast_channel_monitor_stop_type(void);
 
@@ -600,7 +603,7 @@ struct stasis_message_type *ast_channel_monitor_stop_type(void);
  * \since 18
  * \brief Message type for starting mixmonitor on a channel
  *
- * \retval A stasis message type
+ * \return A stasis message type
  */
 struct stasis_message_type *ast_channel_mixmonitor_start_type(void);
 
@@ -608,7 +611,7 @@ struct stasis_message_type *ast_channel_mixmonitor_start_type(void);
  * \since 18
  * \brief Message type for stopping mixmonitor on a channel
  *
- * \retval A stasis message type
+ * \return A stasis message type
  */
 struct stasis_message_type *ast_channel_mixmonitor_stop_type(void);
 
@@ -616,7 +619,7 @@ struct stasis_message_type *ast_channel_mixmonitor_stop_type(void);
  * \since 18
  * \brief Message type for muting or unmuting mixmonitor on a channel
  *
- * \retval A stasis message type
+ * \return A stasis message type
  */
 struct stasis_message_type *ast_channel_mixmonitor_mute_type(void);
 
@@ -624,7 +627,7 @@ struct stasis_message_type *ast_channel_mixmonitor_mute_type(void);
  * \since 18.0.0
  * \brief Message type for agent login on a channel
  *
- * \retval A stasis message type
+ * \return A stasis message type
  */
 struct stasis_message_type *ast_channel_agent_login_type(void);
 
@@ -632,7 +635,7 @@ struct stasis_message_type *ast_channel_agent_login_type(void);
  * \since 12.0.0
  * \brief Message type for agent logoff on a channel
  *
- * \retval A stasis message type
+ * \return A stasis message type
  */
 struct stasis_message_type *ast_channel_agent_logoff_type(void);
 
@@ -640,7 +643,7 @@ struct stasis_message_type *ast_channel_agent_logoff_type(void);
  * \since 12
  * \brief Message type for starting music on hold on a channel
  *
- * \retval A stasis message type
+ * \return A stasis message type
  */
 struct stasis_message_type *ast_channel_moh_start_type(void);
 
@@ -648,7 +651,7 @@ struct stasis_message_type *ast_channel_moh_start_type(void);
  * \since 12
  * \brief Message type for stopping music on hold on a channel
  *
- * \retval A stasis message type
+ * \return A stasis message type
  */
 struct stasis_message_type *ast_channel_moh_stop_type(void);
 
@@ -656,7 +659,7 @@ struct stasis_message_type *ast_channel_moh_stop_type(void);
  * \since 12.4.0
  * \brief Message type for a channel starting talking
  *
- * \retval A stasis message type
+ * \return A stasis message type
  */
 struct stasis_message_type *ast_channel_talking_start(void);
 
@@ -664,7 +667,7 @@ struct stasis_message_type *ast_channel_talking_start(void);
  * \since 12.4.0
  * \brief Message type for a channel stopping talking
  *
- * \retval A stasis message type
+ * \return A stasis message type
  */
 struct stasis_message_type *ast_channel_talking_stop(void);
 
@@ -714,7 +717,7 @@ void ast_channel_publish_dial_forward(struct ast_channel *caller,
  * \param sanitize The message sanitizer to use on the snapshot
  *
  * \return JSON object representing channel snapshot.
- * \return \c NULL on error
+ * \retval NULL on error
  */
 struct ast_json *ast_channel_snapshot_to_json(const struct ast_channel_snapshot *snapshot,
 	const struct stasis_message_sanitizer *sanitize);
@@ -726,8 +729,8 @@ struct ast_json *ast_channel_snapshot_to_json(const struct ast_channel_snapshot
  * \param old_snapshot Old snapshot
  * \param new_snapshot New snapshot
  *
- * \return True (non-zero) if context, exten or priority are identical.
- * \return False (zero) if context, exten and priority changed.
+ * \retval True (non-zero) if context, exten or priority are identical.
+ * \retval False (zero) if context, exten and priority changed.
  */
 int ast_channel_snapshot_cep_equal(
 	const struct ast_channel_snapshot *old_snapshot,
@@ -740,8 +743,8 @@ int ast_channel_snapshot_cep_equal(
  * \param old_snapshot Old snapshot
  * \param new_snapshot New snapshot
  *
- * \return True (non-zero) if callerid are identical.
- * \return False (zero) if callerid changed.
+ * \retval True (non-zero) if callerid are identical.
+ * \retval False (zero) if callerid changed.
  */
 int ast_channel_snapshot_caller_id_equal(
 	const struct ast_channel_snapshot *old_snapshot,
@@ -754,8 +757,8 @@ int ast_channel_snapshot_caller_id_equal(
  * \param old_snapshot Old snapshot
  * \param new_snapshot New snapshot
  *
- * \return True (non-zero) if callerid are identical.
- * \return False (zero) if callerid changed.
+ * \retval True (non-zero) if callerid are identical.
+ * \retval False (zero) if callerid changed.
  */
 int ast_channel_snapshot_connected_line_equal(
 	const struct ast_channel_snapshot *old_snapshot,
@@ -763,8 +766,8 @@ int ast_channel_snapshot_connected_line_equal(
 
 /*!
  * \brief Initialize the stasis channel topic and message types
- * \return 0 on success
- * \return Non-zero on error
+ * \retval 0 on success
+ * \retval Non-zero on error
  */
 int ast_stasis_channels_init(void);
 
